summaryrefslogtreecommitdiff
path: root/inc
diff options
context:
space:
mode:
Diffstat (limited to 'inc')
-rw-r--r--inc/html.php7
1 files changed, 4 insertions, 3 deletions
diff --git a/inc/html.php b/inc/html.php
index 4a56072e1..320bfcf67 100644
--- a/inc/html.php
+++ b/inc/html.php
@@ -1012,8 +1012,9 @@ function html_updateprofile(){
/**
* This displays the edit form (lots of logic included)
*
* @fixme this is a huge lump of code and should be modularized
* @author Andreas Gohr <andi@splitbrain.org>
*/
function html_edit($text=null,$include='edit'){ //FIXME: include needed?
global $ID;
@@ -1047,7 +1048,7 @@ function html_edit($text=null,$include='edit'){ //FIXME: include needed?
}
}else{
//try to load a pagetemplate
- $text = pageTemplate($ID);
+ $text = trigger_event('HTML_EDIT_PAGETEMPLATE',array($ID),'pageTemplate',true);
}
}else{
$pr = true; //preview mode
@@ -1012,8 +1012,9 @@ function html_updateprofile(){
* This displays the edit form (lots of logic included)
*
- * @fixme this is a huge lump of code and should be modularized
- * @author Andreas Gohr <andi@splitbrain.org>
+ * @fixme this is a huge lump of code and should be modularized
+ * @triggers HTML_EDIT_PAGETEMPLATE
+ * @author Andreas Gohr <andi@splitbrain.org>
*/
function html_edit($text=null,$include='edit'){ //FIXME: include needed?